@@ -1,12 +1,11 @@
 package PICA::Parser::Plus;
 # ABSTRACT: PICA+ format parser
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use strict;
 use charnames qw< :full >;
 use Carp qw(croak);
 
-use constant LEADER_LEN         => 24;
 use constant SUBFIELD_INDICATOR => "\N{INFORMATION SEPARATOR ONE}";
 use constant END_OF_FIELD       => "\N{INFORMATION SEPARATOR TWO}";
 use constant END_OF_RECORD      => "\N{LINE FEED}"; # TODO
@@ -60,7 +59,7 @@ sub _decode {
     my @fields = split( END_OF_FIELD, $reader );
     my @record;
 
-    if (length($fields[0]) == LEADER_LEN-1 && $fields[0] !~ m/.*SUBFIELD_INDICATOR/){
+    if ($fields[0] !~ m/.*SUBFIELD_INDICATOR/){
         # drop leader because usage is unclear
         shift(@fields);
     }
@@ -98,7 +97,7 @@ PICA::Parser::Plus - PICA+ format parser
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
